//
//  LifeManager.swift
//  Life Saver
//
//  Created by Brad Root on 5/21/19.
//  Copyright © 2019 Brad Root. All rights reserved.
//

import Foundation
import ScreenSaver
import SpriteKit

final class LifeManager {
    private(set) var appearanceMode: Appearance
    private(set) var squareSize: SquareSize
    private(set) var animationSpeed: AnimationSpeed
    private(set) var color1: SKColor
    private(set) var color2: SKColor
    private(set) var color3: SKColor

    init() {
        appearanceMode = LifeDatabase.standard.appearanceMode
        squareSize = LifeDatabase.standard.squareSize
        animationSpeed = LifeDatabase.standard.animationSpeed
        color1 = LifeDatabase.standard.getColor(.color1)
        color2 = LifeDatabase.standard.getColor(.color2)
        color3 = LifeDatabase.standard.getColor(.color3)
    }

    func setAppearanceMode(_ appearanceMode: Appearance) {
        self.appearanceMode = appearanceMode
        LifeDatabase.standard.set(appearanceMode: appearanceMode)
    }

    func setSquareSize(_ squareSize: SquareSize) {
        self.squareSize = squareSize
        LifeDatabase.standard.set(squareSize: squareSize)
    }

    func setAnimationSpeed(_ animationSpeed: AnimationSpeed) {
        self.animationSpeed = animationSpeed
        LifeDatabase.standard.set(animationSpeed: animationSpeed)
    }

    func setColor(_ color: SKColor, for colors: Colors) {
        switch colors {
        case .color1:
            color1 = color
        case .color2:
            color2 = color
        case .color3:
            color3 = color
        }
        LifeDatabase.standard.set(color, for: colors)
    }
}
